local autoWatchZone = true
local hiddenQuests = {}
local currentZone = "none"

local function PrintWatchedQuests()
  local quests = Inspect.Quest.Detail(Inspect.Quest.List())
  for qID, quest in pairs(quests) do
    if quest.watch then
      print(quest.name.." "..quest.categoryName)
      dump(quest)
    end
  end
end

local function SetWatchByCategory(category, watch)
  local quests = Inspect.Quest.Detail(Inspect.Quest.List())
  for qID, quest in pairs(quests) do
    if (not quest.domain) and quest.categoryName == category then
      Command.Quest.Watch(qID, watch)
    end
  end
end

local function SetWatchByComplete(watch)
  local quests = Inspect.Quest.Detail(Inspect.Quest.List())
  for qID, quest in pairs(quests) do
    if (not quest.domain) and quest.complete then
      Command.Quest.Watch(qID, watch)
    end
  end
end


local function HideWatchedQuests(store)
  local quests = Inspect.Quest.Detail(Inspect.Quest.List())
  for qID, quest in pairs(quests) do
    if (not quest.domain) and quest.watch then
      if store then hiddenQuests[qID] = true end
      Command.Quest.Watch(qID, false)
    end
  end
--  dump(hiddenQuests)
end

local function RestoreWatchedQuests()
  for qID, _ in pairs(hiddenQuests) do
    Command.Quest.Watch(qID, true)
  end
  hiddenQuests = {}
end

local function ToggleAutoWatchZone()
  autoWatchZone = not autoWatchZone
  if autoWatchZone then
    return "on"
  else
    return "off"
  end
end

local function EventZoneChange(h, zoneName)
  if not autoWatchZone then return end
  SetWatchByCategory(currentZone, false)
  currentZone = zoneName
  SetWatchByCategory(currentZone, true)
  print("Watching quests for "..currentZone)
end

local function SlashCommandHandler(h, args)
  if args == "list" then
    PrintWatchedQuests()
  elseif args == "hide" then
    HideWatchedQuests(true)
  elseif args == "hide complete" then
    SetWatchByComplete(false)
  elseif args == "restore" then
    RestoreWatchedQuests()
  elseif args == "autowatchzone" then
    print("autowatchzone is "..ToggleAutoWatchZone())
  elseif args == "watch profession" then
    SetWatchByCategory("Profession", true)
  else
    print("Usage:")
    print("/qwa hide  - hides curently watched quests")
    print("/qwa restore  - restores watched quests hidden by /qwa hide")
    print("   Restore doesn't remember hidden quests across sessions")
    print("/qwa hide complete  - hides quests that are complete and waiting to be returned")
    print("/qwa watch profession  - adds all current profession quests to watchlist")
    print("/qwa autowatchzone  - toggles between autowatchzone on or off")
  end
end

Command.Event.Attach(Library.libZoneChange.Player, EventZoneChange, "Library.LibZoneChange.Player")

Command.Event.Attach(Command.Slash.Register("qwa"), SlashCommandHandler, "Command.Slash.Register: qwa")